from .sql import *



def sql_executar_comando(comando):
    try:
        conexao.commit()

        cursor.execute(comando)
        conexao.commit()

        return True
    except:
        return [False, 'Erro ao executar a função']
    finally:
        cursor.close()  
        conexao.close()

    
def sql_consultar_dado(comando):
    try:
        conexao.commit()
        cursor.execute(comando)
        resultado = cursor.fetchall()

        return resultado
    except:
        return [False, 'Erro ao executar a função']     
    finally:
        cursor.close()  
        conexao.close()


from .infos import *
from colorama import init, Fore, Back
import os



init()
gerar_logs = False
estado_console_log = False


def configurar_log(criar_logs:bool=False,exibir_logs_em_console:bool=False):
    global gerar_logs
    global estado_console_log
    gerar_logs = criar_logs
    estado_console_log = exibir_logs_em_console


def verificar_status_log():
    global gerar_logs
    return gerar_logs

    
def gerar_log(tipo:str,conteudo:str):
    if gerar_logs == True:
        data_atual = retornar_data_atual("%d-%m-%Y")
        hora_atual = retornar_hora_atual()

        tipo = tipo.upper()

        conteudo = f'{tipo}: {conteudo} || DATA: {data_atual} || HORA: {hora_atual}\n'
        with open('log.txt', 'a') as arquivo:
            arquivo.write(conteudo)

        if estado_console_log == True:
            os.system("cls")
            print(Fore.RED + conteudo)

        return True
    else:
        print(Fore.RED + "ERRO: Gerar Log está desativado! Para ativar use a função 'configLog()'")


from hashlib import sha256
import random
import string



def criptografar_SHA256(arg:str):
    hash = sha256(arg.encode())
    resultado = hash.hexdigest()
    return resultado


def criptografar_SALT():
    caracteres = string.ascii_letters + string.digits + string.punctuation
    return ''.join(random.choice(caracteres) for _ in range(32))


def criptografar_SHA256_SALT(arg:str):
    salt = criptografar_SALT()
    hashFinal = arg+salt
    hashFinal = criptografar_SHA256(hashFinal)

    return {'salt':salt,'hashFinal':hashFinal}


import smtplib
import email.message
from datetime import datetime


def quebrar_frase(frase):
    pass


def enviar_verificacao_email(email_remetente,senha_remetente,nome_destinatario,email_destinatario,codigo_verificacao,corpo_do_email=False):
    if corpo_do_email == False:
        corpo_email = f"""
        <p>Olá {nome_destinatario}! Este é o código de verificação:</p>
        <a style='text-decoration:none;text-align:center;cursor: pointer;' target='_blank' href=''><input style='text-align:center;cursor: pointer;border:0;padding:5px;width:100px;height:45px;background-color:black;color:white;' type='button' value='{codigo_verificacao}'></a>
        """

    msg = email.message.Message()
    msg['Subject'] = "Verifique Sua Conta"
    msg['From'] = f'{email_remetente}'
    msg['To'] = f'{email_destinatario}'
    password = f'{senha_remetente}'

    msg.add_header('Content-Type','text/html')
    msg.set_payload(corpo_email)

    s = smtplib.SMTP('smtp.gmail.com:587')
    s.starttls()

    s.login(msg['From'],password)
    s.sendmail(msg['From'],[msg['To']], msg.as_string().encode('utf-8'))
    
    return True   


from datetime import datetime

def retornar_hora_atual():
    hora_atual = datetime.now()
    hora_atual = hora_atual.time()
    hora_atual = str(hora_atual)

    return hora_atual[0:8]


def retornar_data_atual(formato):
    data_atual = datetime.now()
    data_atual = data_atual.date()
    data_atual = data_atual.strftime(formato)

    return data_atual



from .uteis import quebrar_frase

parametros_bloqueados = []
comandos_sql_bloquados = ['WHERE','FROM','SELECT','CREATE',';','=',"'",'"','`','AND','OR','ALTER','TABLE','GROUP BY','NOT','!','--']



def verificar_strings_vazias(*strings):
    for item in strings:
        if (len(item)) <=0:
            return False
        else:
            contador = 0
            for letra in range(len(item)):
                if item[letra] == ' ':
                    contador += 1
            
            if contador >= len(item):
                return True
            else:
                return False
            

def bloquear_parametro(parametro)->bool:
    parametros_bloqueados.append(parametro)
    return True


def verificar_validade_parametro(parametro)->bool:
    parametros = quebrar_frase(parametro)

    for item in parametros:
        if item in parametros_bloqueados:
            return False
    else:
        return True
    




from setuptools import setup

with open("README.md", "r") as arq:
    readme = arq.read()

setup(name='gerenciamento_software',
    version='2.0.2',
    license='MIT License',
    author='George Júnior',
    long_description=readme,
    long_description_content_type="text/markdown",
    author_email='ctt.georgejr@gmail.com',
    keywords='gerenciamento de software',
    description=u'Conjunto De Ferramentas Para Gerenciar Um Software',
    packages=['gerenciamento_software'],
    install_requires=['mysql-connector-python','colorama','psutil',],)



import mysql.connector
from datetime import datetime 
from .criptografia import criptografar_SHA256_SALT          
from .infos import retornar_data_atual, retornar_hora_atual

host_name = ""
user_name = ""
password_name = ""
database_name = ""
conexao = ""
cursor = ""



def sql_conectar_db(host:str,user:str,password:str,database:str):
    global host_name
    global user_name
    global password_name
    global database_name
    global cursor
    global conexao

    host_name = host
    user_name = user
    password_name = password
    database_name = database

    conexao = mysql.connector.connect(
    host= host_name,    
    user= user_name,
    password= password_name,
    database= database_name
    )
    cursor = conexao.cursor()


def sql_criar_conta(tabela:str, coluna_nome:str, coluna_email:str, coluna_senha:str, nome:str, email:str, senha:str,coluna_salt:str,criptografar:bool=False):
    try: 
        if (sql_verificar_uso_email(tabela,email)):
            return [False, 'Email Utilizado']
        else:
            if (verificar_validade_email(email)):
                comando = f'INSERT INTO {tabela} ({coluna_nome},{coluna_email},{coluna_senha}) VALUES("{nome}","{email}","{senha}")'

                if (criptografar):
                    hash = criptografar_SHA256_SALT(senha)
                    salt = hash['salt']
                    senha = hash['hashFinal']
                    comando = f'INSERT INTO {tabela} ({coluna_nome},{coluna_email},{coluna_senha},{coluna_salt}) VALUES("{nome}","{email}","{senha}","{salt}")'
                
                cursor.execute(comando)
                conexao.commit()

                return True
            else:
                return [False, 'Insira um email válido']
    except:
        return [False, 'Erro ao tentar executar a função']
    finally:
        cursor.close()  
        conexao.close()
          

def sql_logar_conta(tabela:str, coluna_email:str, coluna_senha:str, email:str, senha:str, coluna_salt:str, criptografar:bool=False):
    try:
        conexao.commit()

        if (criptografar):
            pegando_salt = f'SELECT {coluna_salt} FROM {tabela} WHERE {coluna_email}="{email}"'
            cursor.execute(comando)
            salt = cursor.fetchall()

            if ((len(salt)) <=0):
                return [False, 'Conta nao encontrada']
            else:
                salt = salt[0]
                hash_consulta = senha+salt
                hashFinal = criptografar_SHA256_SALT(hash_consulta)
                senha = hashFinal['hashFinal']

        comando = f'SELECT * FROM {tabela} WHERE {coluna_email}="{email}" AND {coluna_senha}="{senha}"'
        cursor.execute(comando)
        resultado = cursor.fetchall()

        if ((len(resultado)) !=0):
            return True
        else:
            return [False, 'Conta não encontrada']
    except:
        return [False, 'Erro ao tentar executar a função']
    finally:
        cursor.close()  
        conexao.close()
              

def sql_alterar_conta(tabela:str,coluna:str,valor,condicao:str):
    try:
        conexao.commit()

        comando = f'UPDATE {tabela} SET {coluna}={valor} WHERE {condicao}'
        cursor.execute(comando)
        conexao.commit()

        return True
    except:
        return [False, 'Erro ao tentar executar a função']
    finally:
        cursor.close()  
        conexao.close()
              

def sql_excluir_conta(tabela:str,condicao:str):
    try:
        conexao.commit()
    
        comando = f'DELETE FROM {tabela} WHERE {condicao}'
        cursor.execute(comando)
        conexao.commit()

        return True
    except:
        return [False, 'Erro ao tentar executar a função']
    finally:
        cursor.close()  
        conexao.close()
        

def sql_registrar_log(tabela_log:str, tabela_usuario:str, coluna_id_log:str, coluna_motivo_log, coluna_data_log:str, coluna_hora_log:str, coluna_id_usuario:str, coluna_email:str, email:str, motivo_log:str):
    try:
        conexao.commit()

        data = retornar_data_atual("%Y-%m-%d")
        hora = retornar_hora_atual()
        id = sql_retornar_id_usuario(tabela_usuario,coluna_id_usuario,coluna_email,email)

        comando = f'INSERT INTO {tabela_log} ({coluna_id_log},{coluna_motivo_log},{coluna_data_log},{coluna_hora_log}) VALUES("{id}","{motivo_log}","{data}","{hora}")'
        cursor.execute(comando)
        conexao.commit()

        return True
    except:
        return [False, 'Erro ao executar a função']
    finally:
        cursor.close()  
        conexao.close()


def sql_verificar_uso_email(tabela:str, email:str):
    try:
        conexao.commit()

        comando = f'SELECT * FROM {tabela} WHERE email = "{email}"'
        cursor.execute(comando)
        resultado = cursor.fetchall()

        if ((len(resultado)) != 0):
            return True
        else:
            return False
    finally:
        cursor.close()  
        conexao.close()

    
def sql_retornar_id_usuario(tabela:str, coluna_id:str, coluna_email:str, email:str):
    try:
        conexao.commit()

        comando = f'SELECT {coluna_id} FROM {tabela} WHERE {coluna_email} = "{email}"'
        cursor.execute(comando)
        id_usuario = cursor.fetchall()
        id_usuario = id_usuario[0][0]

        return int(id_usuario)
    except:
        return [False, 'Erro ao tentar executar a função']
    finally:
        cursor.close()  
        conexao.close()
          
  
def verificar_validade_email(email:str):
  if '@' in email and '.' in email:
    return True
  else:
    return False